==> aptechka-0.42.5.tgz: package/lib/ticker/index.js <==
var q = (r) => {
  throw TypeError(r);
};
var L = (r, i, s) => i.has(r) || q("Cannot " + s);
var e = (r, i, s) => (L(r, i, "read from private field"), s ? s.call(r) : i.get(r)), h = (r, i, s) => i.has(r) ? q("Cannot add the same private member more than once") : i instanceof WeakSet ? i.add(r) : i.set(r, s), t = (r, i, s, n) => (L(r, i, "write to private field"), n ? n.call(r, s) : i.set(r, s), s), A = (r, i, s) => (L(r, i, "access private method"), s);
import { i as S } from "../browser-0zX67oeU.js";
import { g as P } from "../dom-CVWzyXPH.js";
var o, u, v, m, b, l, g, F, E;
class V {
  constructor(i, s) {
    h(this, o);
    h(this, u);
    h(this, v);
    h(this, m, 0);
    h(this, b, 0);
    h(this, l, 0);
    h(this, g, !1);
    h(this, F, null);
    h(this, E, (i) => {
      const s = i[0];
      t(this, g, s.isIntersecting);
    });
    if (t(this, o, i), t(this, u, s == null ? void 0 : s.maxFPS), t(this, v, (s == null ? void 0 : s.order) || 0), s != null && s.culling && S) {
      const n = P(s.culling);
      n && (t(this, F, new IntersectionObserver(
        e(this, E)
      )), e(this, F).observe(n));
    } else
      t(this, g, !0);
  }
  get callback() {
    return e(this, o);
  }
  get order() {
    return e(this, v);
  }
  sync(i) {
    t(this, m, i - e(this, l));
  }
  tick(i) {
    if (t(this, l, Math.max(0, i - e(this, m))), e(this, b) || t(this, b, i), e(this, u))
      if (e(this, l) >= 1e3 / e(this, u))
        t(this, m, i - e(this, l) % e(this, u));
      else
        return;
    else
      t(this, m, i);
    e(this, g) && e(this, o).call(this, {
      timeBetweenFrames: e(this, l),
      timestamp: i,
      subscribeTimestamp: e(this, b),
      timeElapsedSinceSubscription: i - e(this, b)
    });
  }
  destroy() {
    var i;
    (i = e(this, F)) == null || i.disconnect();
  }
}
o = new WeakMap(), u = new WeakMap(), v = new WeakMap(), m = new WeakMap(), b = new WeakMap(), l = new WeakMap(), g = new WeakMap(), F = new WeakMap(), E = new WeakMap();
var k, f, a, y, c, d, B, x, w, T;
class C {
  constructor() {
    h(this, d);
    h(this, k, 0);
    h(this, f, 0);
    h(this, a);
    h(this, y, !1);
    h(this, c, []);
    h(this, w, (i) => {
      if (e(this, y)) {
        t(this, y, !1), t(this, k, i - e(this, f));
        for (const s of e(this, c))
          s.sync(e(this, f));
      }
      t(this, a, requestAnimationFrame(e(this, w))), t(this, f, i - e(this, k));
      for (const s of e(this, c))
        s.tick(e(this, f));
    });
    h(this, T, () => {
      document.hidden && t(this, y, !0);
    });
    S && document.addEventListener(
      "visibilitychange",
      e(this, T)
    );
  }
  subscribe(i, s) {
    if (!e(this, c).find((n) => n.callback === i)) {
      const n = new V(i, s);
      n.sync(performance.now()), e(this, c).push(n), t(this, c, e(this, c).sort((I, O) => I.order - O.order));
    }
    return A(this, d, B).call(this), () => this.unsubscribe(i);
  }
  unsubscribe(i) {
    const s = e(this, c).filter(
      (n) => n.callback === i
    );
    s.length && (s.forEach((n) => n.destroy()), t(this, c, e(this, c).filter(
      (n) => n.callback !== i
    )), e(this, c).length || A(this, d, x).call(this));
  }
  destroy() {
    S && (A(this, d, x).call(this), document.removeEventListener(
      "visibilitychange",
      e(this, T)
    ));
  }
}
k = new WeakMap(), f = new WeakMap(), a = new WeakMap(), y = new WeakMap(), c = new WeakMap(), d = new WeakSet(), B = function() {
  e(this, c).length && !e(this, a) && t(this, a, requestAnimationFrame(e(this, w)));
}, x = function() {
  e(this, a) && (cancelAnimationFrame(e(this, a)), t(this, a, void 0));
}, w = new WeakMap(), T = new WeakMap();
const j = new C();
export {
  C as Ticker,
  j as ticker
};

==> aptechka-0.47.11.tgz: package/lib/ticker/index.js <==
var q = (r) => {
  throw TypeError(r);
};
var L = (r, i, s) => i.has(r) || q("Cannot " + s);
var e = (r, i, s) => (L(r, i, "read from private field"), s ? s.call(r) : i.get(r)), h = (r, i, s) => i.has(r) ? q("Cannot add the same private member more than once") : i instanceof WeakSet ? i.add(r) : i.set(r, s), t = (r, i, s, n) => (L(r, i, "write to private field"), n ? n.call(r, s) : i.set(r, s), s), A = (r, i, s) => (L(r, i, "access private method"), s);
import { i as S } from "../index-euf5anj6.js";
import { g as P } from "../dom-CVWzyXPH.js";
var o, u, v, m, b, l, g, F, E;
class V {
  constructor(i, s) {
    h(this, o);
    h(this, u);
    h(this, v);
    h(this, m, 0);
    h(this, b, 0);
    h(this, l, 0);
    h(this, g, !1);
    h(this, F, null);
    h(this, E, (i) => {
      const s = i[0];
      t(this, g, s.isIntersecting);
    });
    if (t(this, o, i), t(this, u, s == null ? void 0 : s.maxFPS), t(this, v, (s == null ? void 0 : s.order) || 0), s != null && s.culling && S) {
      const n = P(s.culling);
      n && (t(this, F, new IntersectionObserver(
        e(this, E)
      )), e(this, F).observe(n));
    } else
      t(this, g, !0);
  }
  get callback() {
    return e(this, o);
  }
  get order() {
    return e(this, v);
  }
  sync(i) {
    t(this, m, i - e(this, l));
  }
  tick(i) {
    if (t(this, l, Math.max(0, i - e(this, m))), e(this, b) || t(this, b, i), e(this, u))
      if (e(this, l) >= 1e3 / e(this, u))
        t(this, m, i - e(this, l) % e(this, u));
      else
        return;
    else
      t(this, m, i);
    e(this, g) && e(this, o).call(this, {
      timeBetweenFrames: e(this, l),
      timestamp: i,
      subscribeTimestamp: e(this, b),
      timeElapsedSinceSubscription: i - e(this, b)
    });
  }
  destroy() {
    var i;
    (i = e(this, F)) == null || i.disconnect();
  }
}
o = new WeakMap(), u = new WeakMap(), v = new WeakMap(), m = new WeakMap(), b = new WeakMap(), l = new WeakMap(), g = new WeakMap(), F = new WeakMap(), E = new WeakMap();
var k, f, a, y, c, d, B, x, w, T;
class C {
  constructor() {
    h(this, d);
    h(this, k, 0);
    h(this, f, 0);
    h(this, a);
    h(this, y, !1);
    h(this, c, []);
    h(this, w, (i) => {
      if (e(this, y)) {
        t(this, y, !1), t(this, k, i - e(this, f));
        for (const s of e(this, c))
          s.sync(e(this, f));
      }
      t(this, a, requestAnimationFrame(e(this, w))), t(this, f, i - e(this, k));
      for (const s of e(this, c))
        s.tick(e(this, f));
    });
    h(this, T, () => {
      document.hidden && t(this, y, !0);
    });
    S && document.addEventListener(
      "visibilitychange",
      e(this, T)
    );
  }
  subscribe(i, s) {
    if (!e(this, c).find((n) => n.callback === i)) {
      const n = new V(i, s);
      n.sync(performance.now()), e(this, c).push(n), t(this, c, e(this, c).sort((I, O) => I.order - O.order));
    }
    return A(this, d, B).call(this), () => this.unsubscribe(i);
  }
  unsubscribe(i) {
    const s = e(this, c).filter(
      (n) => n.callback === i
    );
    s.length && (s.forEach((n) => n.destroy()), t(this, c, e(this, c).filter(
      (n) => n.callback !== i
    )), e(this, c).length || A(this, d, x).call(this));
  }
  destroy() {
    S && (A(this, d, x).call(this), document.removeEventListener(
      "visibilitychange",
      e(this, T)
    ));
  }
}
k = new WeakMap(), f = new WeakMap(), a = new WeakMap(), y = new WeakMap(), c = new WeakMap(), d = new WeakSet(), B = function() {
  e(this, c).length && !e(this, a) && t(this, a, requestAnimationFrame(e(this, w)));
}, x = function() {
  e(this, a) && (cancelAnimationFrame(e(this, a)), t(this, a, void 0));
}, w = new WeakMap(), T = new WeakMap();
const j = new C();
export {
  C as Ticker,
  j as ticker
};
